@@ -160,10 +160,14 @@ xmlGetVarStr(const char * msg, va_list args) {
     size = 100;
     length = 0;
 
-    while (1) {                       // From the man page for vsnprintf ....
+    while (1) {
 	left = size - length;
 		    /* Try to print in the allocated space. */
-	chars = vsnprintf(str + length, left, msg, args);
+#ifdef HAVE_VSNPRINTF
+  	chars = vsnprintf(str + length, left, msg, args);
+#else
+	chars = vsprintf(str + length, msg, args);
+#endif
 			  /* If that worked, we're done. */
 	if ((chars > -1) && (chars < left ))
 	    break;
@@ -214,7 +218,8 @@ xmlParserError(void *ctx, const char *msg, ...)
     str = xmlGetVarStr(msg, args);
     va_end(args);
     xmlGenericError(xmlGenericErrorContext, str);
-    xmlFree(str);
+    if (str != NULL)
+	xmlFree(str);
 
     if (ctxt != NULL) {
 	xmlParserPrintFileContext(input);
@@ -259,7 +264,8 @@ xmlParserWarning(void *ctx, const char *msg, ...)
     str = xmlGetVarStr(msg, args);
     va_end(args);
     xmlGenericError(xmlGenericErrorContext, str);
-    xmlFree(str);
+    if (str != NULL)
+	xmlFree(str);
 
     if (ctxt != NULL) {
 	xmlParserPrintFileContext(input);
@@ -291,6 +297,7 @@ xmlParserValidityError(void *ctx, const char *msg, ...)
 {
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     xmlParserInputPtr input = NULL;
+    char * str;
     va_list args;
 
     if (ctxt != NULL) {
@@ -303,8 +310,11 @@ xmlParserValidityError(void *ctx, const char *msg, ...)
 
     xmlGenericError(xmlGenericErrorContext, "validity error: ");
     va_start(args, msg);
-    vfprintf(xmlGenericErrorContext, msg, args);
+    str = xmlGetVarStr(msg, args);
     va_end(args);
+    xmlGenericError(xmlGenericErrorContext, str);
+    if (str != NULL)
+	xmlFree(str);
 
     if (ctxt != NULL) {
 	xmlParserPrintFileContext(input);
@@ -325,6 +335,7 @@ xmlParserValidityWarning(void *ctx, const char *msg, ...)
 {
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     xmlParserInputPtr input = NULL;
+    char * str;
     va_list args;
 
     if (ctxt != NULL) {
@@ -337,8 +348,11 @@ xmlParserValidityWarning(void *ctx, const char *msg, ...)
         
     xmlGenericError(xmlGenericErrorContext, "validity warning: ");
     va_start(args, msg);
-    vfprintf(xmlGenericErrorContext, msg, args);
+    str = xmlGetVarStr(msg, args);
     va_end(args);
+    xmlGenericError(xmlGenericErrorContext, str);
+    if (str != NULL)
+	xmlFree(str);
 
     if (ctxt != NULL) {
 	xmlParserPrintFileContext(input);
